==> wawa-service-api-0.0.19-20180108.055856-20-sources.jar: cn/com/wawa/service/api/query/DeliveryOrderQuery.java <==
package cn.com.wawa.service.api.query;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/12/6.
 */
public class DeliveryOrderQuery implements Serializable {

    private Long id;

    private Long userId;//用户id

    private String logisticsOrderId;//物流单号

    private String phone;//电话

    private Integer deliveryStatus;//状态,1代发货,2已发货

    private String deliveryTime;//发货时间

    private String startTime;//用于导出时间区间圈定,为发货订单创建时间

    private String endTime;//用于导出时间区间圈定,为发货订单创建时间

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getLogisticsOrderId() {
        return logisticsOrderId;
    }

    public void setLogisticsOrderId(String logisticsOrderId) {
        this.logisticsOrderId = logisticsOrderId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getDeliveryStatus() {
        return deliveryStatus;
    }

    public void setDeliveryStatus(Integer deliveryStatus) {
        this.deliveryStatus = deliveryStatus;
    }

    public String getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(String deliveryTime) {
        this.deliveryTime = deliveryTime;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }
}

==> wawa-service-api-0.0.31-sources.jar: cn/com/wawa/service/api/query/DeliveryOrderQuery.java <==
package cn.com.wawa.service.api.query;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by Administrator on 2017/12/6.
 */
public class DeliveryOrderQuery implements Serializable {

    private Long id;

    private Long userId;//用户id

    private String logisticsOrderId;//物流单号

    private String phone;//电话

    private Integer deliveryStatus;//状态,1代发货,2已发货

    private String deliveryTime;//发货时间

    private String startTime;//用于导出时间区间圈定,为发货订单创建时间

    private String endTime;//用于导出时间区间圈定,为发货订单创建时间

    private String erpStatus;//状态,SUCCESS-提交成功,DELIVERY-同步成功

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getLogisticsOrderId() {
        return logisticsOrderId;
    }

    public void setLogisticsOrderId(String logisticsOrderId) {
        this.logisticsOrderId = logisticsOrderId;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public Integer getDeliveryStatus() {
        return deliveryStatus;
    }

    public void setDeliveryStatus(Integer deliveryStatus) {
        this.deliveryStatus = deliveryStatus;
    }

    public String getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(String deliveryTime) {
        this.deliveryTime = deliveryTime;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getErpStatus() {
        return erpStatus;
    }

    public void setErpStatus(String erpStatus) {
        this.erpStatus = erpStatus;
    }
}
